@@ -1,4 +1,4 @@
-"""
+'''
 # aws-events-rule-lambda module
 
 <!--BEGIN STABILITY BANNER-->---
@@ -97,7 +97,7 @@ Out of the box implementation of the Construct without any override will set the
 
 
 © Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-"""
+'''
 import abc
 import builtins
 import datetime
@@ -129,7 +129,7 @@ class EventsRuleToLambda(
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
     ) -> None:
-        """
+        '''
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
@@ -139,7 +139,7 @@ class EventsRuleToLambda(
         :access: public
         :since: 0.8.0
         :summary: Constructs a new instance of the EventsRuleToLambda class.
-        """
+        '''
         props = EventsRuleToLambdaProps(
             event_rule_props=event_rule_props,
             existing_lambda_obj=existing_lambda_obj,
@@ -176,13 +176,13 @@ class EventsRuleToLambdaProps:
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
     ) -> None:
-        """
+        '''
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
         :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
 
         :summary: The properties for the CloudFrontToApiGateway Construct
-        """
+        '''
         if isinstance(event_rule_props, dict):
             event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
         if isinstance(lambda_function_props, dict):
@@ -197,20 +197,20 @@ class EventsRuleToLambdaProps:
 
     @builtins.property
     def event_rule_props(self) -> aws_cdk.aws_events.RuleProps:
-        """User provided eventRuleProps to override the defaults.
+        '''User provided eventRuleProps to override the defaults.
 
         :default: - None
-        """
+        '''
         result = self._values.get("event_rule_props")
         assert result is not None, "Required property 'event_rule_props' is missing"
         return typing.cast(aws_cdk.aws_events.RuleProps, result)
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
-        """Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
+        '''Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
 
         :default: - None
-        """
+        '''
         result = self._values.get("existing_lambda_obj")
         return typing.cast(typing.Optional[aws_cdk.aws_lambda.Function], result)
 
@@ -218,10 +218,10 @@ class EventsRuleToLambdaProps:
     def lambda_function_props(
         self,
     ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
-        """User provided props to override the default props for the Lambda function.
+        '''User provided props to override the default props for the Lambda function.
 
         :default: - Default props are used
-        """
+        '''
         result = self._values.get("lambda_function_props")
         return typing.cast(typing.Optional[aws_cdk.aws_lambda.FunctionProps], result)
 
